pub trait Resolvable { }Expand description
Resolvable is a marker trait, mainly to make resolution opt-in and to avoid
polluting every type with a resolve method.
You might want to use resolvable_with_identity_impl or resolvable_with_try_into_impls
to implement this trait and a reflexive or blanket impl.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".